@@ -8,6 +8,9 @@ head(NYCfevergeo)
 ## -----------------------------------------------------------------------------
 invisible(ss.options(reset=TRUE))
 
+## -----------------------------------------------------------------------------
+invisible(ss.options(reset=TRUE, version="10.1"))
+
 ## -----------------------------------------------------------------------------
 ss.options(list(CaseFile="NYCfever.cas", PrecisionCaseTimes=3))
 ss.options(c("StartDate=2001/11/1","EndDate=2001/11/24"))
@@ -15,6 +18,7 @@ ss.options(list(CoordinatesFile="NYCfever.geo", AnalysisType=4, ModelType=2, Tim
 ss.options(list(UseDistanceFromCenterOption="y", MaxSpatialSizeInDistanceFromCenter=3, NonCompactnessPenalty=0))
 ss.options(list(MaxTemporalSizeInterpretation=1, MaxTemporalSize=7))
 ss.options(list(ProspectiveStartDate="2001/11/24", ReportGiniClusters="n", LogRunToHistoryFile="n"))
+ss.options(list(SaveSimLLRsDBase="y"))
 
 ## -----------------------------------------------------------------------------
 head(ss.options(),3)
@@ -31,7 +35,7 @@ write.geo(NYCfevergeo, td, "NYCfever")
 # SaTScan can be downloaded from www.satscan.org, free of charge
 # you will also find there fully compiled versions of this vignette with results
 
-## NYCfever = satscan(td, "NYCfever", sslocation="C:/Program Files (x86)/SaTScan")
+## NYCfever = satscan(td, "NYCfever", sslocation="C:/Program Files/SaTScan", ssbatchfilename="SaTScanBatch64")
 
 ## -----------------------------------------------------------------------------
 ## summary(NYCfever)
@@ -60,14 +64,14 @@ write.geo(NMgeo, td,"NM")
 write.pop(NMpop, td,"NM")
 
 ## -----------------------------------------------------------------------------
-invisible(ss.options(reset=TRUE))
+invisible(ss.options(reset=TRUE, version="10.1"))
 ss.options(list(CaseFile="NM.cas",StartDate="1973/1/1",EndDate="1991/12/31", 
                 PopulationFile="NM.pop",
                 CoordinatesFile="NM.geo", CoordinatesType=0, AnalysisType=3))
 ss.options(c("NonCompactnessPenalty=0", "ReportGiniClusters=n", "LogRunToHistoryFile=n"))
 
 write.ss.prm(td,"testnm")
-## testnm = satscan(td,"testnm", sslocation="C:/Program Files (x86)/SaTScan")
+## testnm = satscan(td,"testnm", sslocation="C:/Program Files/SaTScan", ssbatchfilename="SaTScanBatch64")
 
 ## -----------------------------------------------------------------------------
 ## summary(testnm)
@@ -87,7 +91,7 @@ write.cas(NHumbersidecas, td, "NHumberside")
 write.ctl(NHumbersidectl, td, "NHumberside")
 write.geo(NHumbersidegeo, td, "NHumberside")
 
-invisible(ss.options(reset=TRUE))
+invisible(ss.options(reset=TRUE, version="10.1"))
 ss.options(list(CaseFile="NHumberside.cas", ControlFile="NHumberside.ctl"))
 ss.options(list(PrecisionCaseTimes=0, StartDate="2001/11/1", EndDate="2001/11/24"))
 ss.options(list(CoordinatesFile="NHumberside.geo", CoordinatesType=0, ModelType=1))
@@ -95,7 +99,7 @@ ss.options(list(TimeAggregationUnits = 3, NonCompactnessPenalty=0))
 ss.options(list(ReportGiniClusters="n", LogRunToHistoryFile="n"))
 
 write.ss.prm(td, "NHumberside")
-## NHumberside = satscan(td, "NHumberside", sslocation="C:/Program Files (x86)/SaTScan")
+## NHumberside = satscan(td, "NHumberside", sslocation="C:/Program Files/SaTScan", ssbatchfilename="SaTScanBatch64")
 
 ## summary(NHumberside)
 
